@@ -1,8 +1,6 @@
-from __future__ import absolute_import
-
 import re
 
-from .base import RegexBasedDetector
+from detect_secrets.plugins.base import RegexBasedDetector
 
 
 class ArtifactoryDetector(RegexBasedDetector):
