@@ -1,14 +1,12 @@
 """
 This plugin searches for Slack tokens
 """
-from __future__ import absolute_import
-
 import re
 
 import requests
 
-from .base import RegexBasedDetector
 from detect_secrets.core.constants import VerifiedResult
+from detect_secrets.plugins.base import RegexBasedDetector
 
 
 class SlackDetector(RegexBasedDetector):
